@@ -1,5 +1,9 @@
 from lino.core.roles import UserRole
 
+class CalendarGuest(UserRole):
+    """Can see and manage their presences in calendar events."""
+    pass
+
 class CalendarReader(UserRole):
     """Has read-only access to calendars of other users."""
     pass
@@ -11,4 +15,3 @@ class GuestOperator(UserRole):
 # class CalendarOperator(UserRole):
 #     """Can modify calendar entries of other users."""
 #     pass
-
