@@ -48,7 +48,7 @@ class InsertEvent(dd.Action):
     label = _("Create new Event")
     icon_name = 'add'  # if action rendered as toolbar button
     help_text = _("Create a new Event")
-    show_in_bbar = True
+    show_in_toolbar = True
 
     def run_from_ui(self, ar, **kw):
         Event = rt.models.cal.Event
