@@ -20,7 +20,7 @@ Place = rt.models.countries.Place
 #         country='EE').build
 #     rumma = company(
 #         'Rumma & Ko OÜ', '78003', 'Vigala', 'Uus tn', '1',
-#         url="http://www.saffre-rumma.net/")
+#         url="https://www.saffre-rumma.net/")
 #     if dd.is_installed('vat'):
 #         rumma.vat_id = "EE100588749"
 #         # a vat_id is required for generating valid XML from payment order
@@ -90,7 +90,7 @@ def objects():
 
     rumma = company(
         'Rumma & Ko OÜ', '78003', vigala, 'Uus tn', '1',
-        url="http://www.saffre-rumma.net/")
+        url="https://www.saffre-rumma.net/")
     if dd.is_installed('vat'):
         rumma.vat_id = "EE100588749"
         # a vat_id is required for generating valid XML from payment order
