@@ -181,102 +181,51 @@ class ContactRelated(AbstractContactRelated):
         blank=True, null=True)
 
 
+class PartnerRelated(dd.Model):
+    class Meta:
+        abstract = True
 
-class PartnerDocument(dd.Model):
+    partner = dd.ForeignKey(
+        'contacts.Partner',
+        related_name="%(app_label)s_%(class)s_set_by_partner",
+        blank=True, null=True)
+
+    def get_partner(self):
+        """Overrides Voucher.get_partner"""
+        return self.partner
+
+    @classmethod
+    def get_partner_filter_field(cls, partner):
+        return 'partner'
+
+    def get_print_language(self):
+        p = self.get_partner()
+        if p is not None:
+            return p.language
+
+    def get_recipient(self):
+        return self.get_partner()
+    recipient = property(get_recipient)
+
+    def partner_changed(self, ar=None):
+        # does nothing but we need it so that subclasses like
+        # BankAccount can call super().partner_changed()
+        pass
+
+    @classmethod
+    def get_registrable_fields(cls, site):
+        for f in super().get_registrable_fields(site):
+            yield f
+        yield 'partner'
+
+
+class PartnerPrintable(dd.Model):
 
     class Meta:
         abstract = True
 
-    company = dd.ForeignKey("contacts.Company", blank=True, null=True)
-    person = dd.ForeignKey("contacts.Person", blank=True, null=True)
+    language = dd.LanguageField()
 
-    def get_partner(self):
-        if self.company is not None:
-            return self.company
-        return self.person
-
-    def get_mailable_recipients(self):
-        for p in self.company, self.person:
-            if p is not None and p.email:
-                #~ yield "%s <%s>" % (p, p.email)
-                yield ('to', p)
-                #~ yield ('to', unicode(p), p.email)
-
-    def get_postable_recipients(self):
-        for p in self.company, self.person:
-            if p is not None:
-                yield p
-
-    def summary_row(self, ar, **kw):
-        """
-        A :meth:`lino.core.model.Model.summary_row`
-        method for partner documents.
-        """
-        href_to = ar.obj2html
-        s = [href_to(self)]
-        #~ if self.person and not dd.has_fk(rr,'person'):
-        if self.person:
-            if self.company:
-                s += [" (", href_to(self.person),
-                      "/", href_to(self.company), ")"]
-            else:
-                s += [" (", href_to(self.person), ")"]
-        elif self.company:
-            s += [" (", href_to(self.company), ")"]
-        return s
-
-    def update_owned_instance(self, other):
-        #~ print '20120627 PartnerDocument.update_owned_instance'
-        if isinstance(other, dd.ProjectRelated):
-            if isinstance(self.person, rt.models.contacts.Person):
-                other.project = self.person
-            elif isinstance(self.company, rt.models.contacts.Person):
-                other.project = self.company
-        other.person = self.person
-        other.company = self.company
-        super().update_owned_instance(other)
-
-
-# class OldCompanyContact(dd.Model):
-#
-#     """
-#     Abstract class which adds two fields `company` and `contact`.
-#     """
-#     class Meta(object):
-#         abstract = True
-#
-#     company = dd.ForeignKey(
-#         "contacts.Company",
-#         related_name="%(app_label)s_%(class)s_set_by_company",
-#         verbose_name=_("Company"),
-#         blank=True, null=True)
-#
-#     contact = dd.ForeignKey(
-#         "contacts.Role",
-#         related_name="%(app_label)s_%(class)s_set_by_contact",
-#         blank=True, null=True,
-#         verbose_name=_("represented by"))
-#
-#     @dd.chooser()
-#     def contact_choices(cls, company):
-#         if company is not None:
-#             return cls.contact_choices_queryset(company)
-#         return []
-#
-#     @classmethod
-#     def contact_choices_queryset(cls, company):
-#         return rt.models.contacts.Role.objects.filter(company=company)
-#
-#     def full_clean(self, *args, **kw):
-#         if self.company:
-#             if self.contact is None \
-#                 or self.contact.company is None \
-#                     or self.contact.company.pk != self.company.pk:
-#                 qs = self.contact_choices_queryset(self.company)
-#                 #~ qs = self.company.rolesbyparent.all()
-#                 if qs.count() == 1:
-#                     self.contact = qs[0]
-#                 else:
-#                     #~ print "20120227 clear contact!"
-#                     self.contact = None
-#         super().full_clean(*args, **kw)
+    def get_print_language(self):
+        return self.language or self.get_partner().language or \
+            dd.get_default_language()
