@@ -154,7 +154,7 @@ class ExportVCardFile(dd.Action):
     icon_name = 'vcard'
     sort_index = -9
     default_format = 'ajax'
-    show_in_bbar = True
+    show_in_toolbar = True
 
     def run_from_ui(self, ar, **kw):
         #~ print 20130912
@@ -182,7 +182,7 @@ class ImportText(dd.Action):
     sort_index = -10
     select_rows = False
     http_method = 'POST'
-    show_in_bbar = True
+    show_in_toolbar = True
 
     parameters = dict(
         text=dd.RichTextField(_("One line per contact"), format='plain'),
