@@ -205,9 +205,9 @@ class Course(Reservation, Duplicable, Printable):
     enrolments_until = models.DateField(
         _("Enrolments until"), blank=True, null=True)
 
-    print_presence_sheet = PrintPresenceSheet(show_in_bbar=False)
+    print_presence_sheet = PrintPresenceSheet(show_in_toolbar=False)
     print_presence_sheet_html = PrintPresenceSheet(
-        show_in_bbar=False,
+        show_in_toolbar=False,
         build_method='weasy2html',
         label=format_lazy(u"{}{}",_("Presence sheet"), _(" (HTML)")))
 
@@ -732,3 +732,6 @@ def setup_memo_commands(sender=None, **kwargs):
         cmd=cmd,
         # title=lambda obj: obj.name
     )
+
+
+from .ui import *
