@@ -22,6 +22,7 @@ from etgen.html import E
 from lino import mixins
 from lino.api import dd, rt, gettext, _
 from lino.utils import join_elems
+from lino.core import constants
 from lino.core.keyboard import Hotkey
 from lino.core.exceptions import UnresolvedChoice
 from lino.modlib.gfks.mixins import Controllable
@@ -709,7 +710,7 @@ class ExcerptsByOwner(Excerpts):
     label = _("Existing excerpts")
     column_names = "build_time excerpt_type user project *"
     order_by = ['-build_time', 'id']
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
     auto_fit_column_widths = True
     MORE_LIMIT = 5
 
