@@ -52,15 +52,15 @@ class Group(mixins.BabelNamed, mixins.Referrable, ChangeNotifier,
         if ar is None:
             return ''
         cls = rt.models.comments.CommentsByRFC
-        sar = cls.request_from(
-            ar, master_instance=self, limit=3)
+        sar = cls.request(
+            parent=ar, master_instance=self, limit=3)
         chunks = []
         for com in sar.sliced_data_iterator:
             chunks.append(ar.obj2html(com, str(com)))
         chunks.append("...")
         chunks = join_elems(chunks, ', ')
 
-        sar = cls.insert_action.request_from(sar)
+        sar = cls.insert_action.request(parent=sar)
         if sar.get_permission():
             btn = sar.ar2button(None, _("Write comment"), icon_name=None)
             chunks.append(" ")
@@ -166,7 +166,7 @@ class MembershipsByGroup(Memberships):
 
     @classmethod
     def unused_get_table_summary(self, obj, ar):
-        sar = self.request_from(ar, master_instance=obj)
+        sar = self.request(parent=ar, master_instance=obj)
         chunks = []
 
         for mbr in sar:
