@@ -42,7 +42,7 @@ class Types(dd.Table):
 
 class PopulateMembers(dd.Action):
     # populate household members from data in humanlinks
-    # show_in_bbar = False
+    # show_in_toolbar = False
     custom_handler = True
     label = _("Populate")
     icon_name = 'lightning'
@@ -487,7 +487,7 @@ class SiblingsByPerson(Members):
 
 
 class CreateHousehold(dd.Action):
-    show_in_bbar = False
+    show_in_toolbar = False
     custom_handler = True
     label = _("Create Household")
     parameters = dict(
