@@ -6,9 +6,11 @@ from django.db import models
 from django.conf import settings
 from django.utils.text import format_lazy
 from django.utils import translation
+from django.core.exceptions import ValidationError
 
 # from etgen.html import E, join_elems
 from lino.core.gfks import GenericForeignKey, ContentType
+from lino.core import constants
 from lino.modlib.gfks.fields import GenericForeignKeyIdField
 # from lino.core.gfks import gfk2lookup
 from lino.utils.mldbc.mixins import BabelDesignated
@@ -25,17 +27,16 @@ from lino_xl.lib.ledger.roles import LedgerUser, LedgerStaff
 from lino_xl.lib.ledger.mixins import JournalRef
 # from lino_xl.lib.cal.choicelists import DurationUnits
 
-from .mixins import InvoiceGenerator
+from .mixins import InvoiceGenerator, InvoicingAreas
 # from .choicelists import InvoicingCycles
 # from .choicelists import InvoicingDepartments
 from .actions import (ToggleSelection, StartInvoicing,
-                      # StartInvoicingByArea,
+                      StartInvoicingByArea,
                       StartInvoicingForPartner, StartInvoicingForOrder,
                       ExecutePlan, ExecuteItem)
 
 
 order_model = dd.plugins.invoicing.order_model
-invoiceable_label = dd.plugins.invoicing.invoiceable_label
 generator_label = _("Generator")
 
 # if dd.is_installed('invoicing'):
@@ -51,20 +52,38 @@ class FollowUpRule(Sequenced):
         verbose_name = _("Follow-up rule")
         verbose_name_plural = _("Follow-up rules")
 
+    invoicing_area = InvoicingAreas.field()
+    # source_journal = dd.ForeignKey(
+    #     'ledger.Journal', related_name="followup_source")
     source_journal = dd.ForeignKey(
         'ledger.Journal', related_name="followup_source")
-    target_journal = dd.ForeignKey(
-        'ledger.Journal', related_name="followup_target")
-    # from_state = InvoicingState.field()
-    # to_state = InvoicingState.field()
+#     # from_state = InvoicingArea.field()
+#     # to_state = InvoicingArea.field()
+#
+    allow_cascaded_delete = "invoicing_area source_journal"
 
-    allow_cascaded_delete = "source_journal target_journal"
+    @dd.chooser()
+    def source_journal_choices(cls, invoicing_area):
+        if not invoicing_area:
+            return []
+        return invoicing_area.get_source_journals()
+
+#     def full_clean(self, *args, **kw):
+#         super().full_clean(*args, **kw)
+#         area = self.invoicing_area
+#         jnl = self.source_journal
+#         if not issubclass(jnl.voucher_type.table_class, area.journal_table):
+#             raise ValidationError("{} is not a valid source journal for {}".format(jnl, area))
+#
+#     @classmethod
+#     def find_for_model(cls, model):
+#         return cls.objects.filter(source_journal=journal).first()
 
 
 class FollowUpRules(dd.Table):
     model = 'invoicing.FollowUpRule'
     # required_roles = dd.login_required(LedgerStaff)
-    column_names = 'source_journal target_journal *'
+    column_names = 'invoicing_area source_journal *'
 
 
 class SalesRule(dd.Model):
@@ -118,8 +137,7 @@ class PartnersByInvoiceRecipient(SalesRules):
 
 dd.inject_action(
     'contacts.Partner',
-    show_invoice_partners=dd.ShowSlaveTable(
-        PartnersByInvoiceRecipient))
+    show_invoice_partners=dd.ShowSlaveTable(PartnersByInvoiceRecipient))
 
 
 # class SubscriptionType(BabelDesignated):
@@ -182,43 +200,44 @@ class Tariffs(dd.Table):
     order_by = ['designation']
 
 
-class Area(BabelDesignated, Sequenced):
-    class Meta:
-        app_label = 'invoicing'
-        abstract = dd.is_abstract_model(__name__, 'Area')
-        verbose_name = _("Invoicing area")
-        verbose_name_plural = _("Invoicing areas")
-
-    # designation = dd.CharField(max_length=100)
-    journal = dd.ForeignKey('ledger.Journal', blank=True, null=True)
-
-    # start_invoicing = StartInvoicingForArea()
-
-    # def __str__(self):
-    #     return str(self.designation)
-
-    @dd.chooser()
-    def journal_choices(cls):
-        vt = dd.plugins.invoicing.get_voucher_type()
-        return rt.models.ledger.Journal.objects.filter(voucher_type=vt)
-
-    def full_clean(self):
-        if self.journal is None:
-            vt = dd.plugins.invoicing.get_voucher_type()
-            # print("20220707", vt, vt.get_journals())
-            self.journal = vt.get_journals().first()
-            # raise Exception("20220707")
-
-        # if not self.designation:
-        #     self.designation = str(self.journal)
-        super(Area, self).full_clean()
-
-
-class Areas(dd.Table):
-    required_roles = dd.login_required(LedgerStaff)
-    model = "invoicing.Area"
-    column_names = "seqno designation journal *"
 
+# class Area(BabelDesignated, Sequenced):
+#     class Meta:
+#         app_label = 'invoicing'
+#         abstract = dd.is_abstract_model(__name__, 'Area')
+#         verbose_name = _("Invoicing area")
+#         verbose_name_plural = _("Invoicing areas")
+#
+#     # designation = dd.CharField(max_length=100)
+#     journal = dd.ForeignKey('ledger.Journal', blank=True, null=True)
+#
+#     # start_invoicing = StartInvoicingForArea()
+#
+#     # def __str__(self):
+#     #     return str(self.designation)
+#
+#     @dd.chooser()
+#     def journal_choices(cls):
+#         vt = dd.plugins.invoicing.get_voucher_type()
+#         return rt.models.ledger.Journal.objects.filter(voucher_type=vt)
+#
+#     def full_clean(self):
+#         if self.journal is None:
+#             vt = dd.plugins.invoicing.get_voucher_type()
+#             # print("20220707", vt, vt.get_journals())
+#             self.journal = vt.get_journals().first()
+#             # raise Exception("20220707")
+#
+#         # if not self.designation:
+#         #     self.designation = str(self.journal)
+#         super(Area, self).full_clean()
+#
+#
+# class Areas(dd.Table):
+#     required_roles = dd.login_required(LedgerStaff)
+#     model = "invoicing.Area"
+#     column_names = "seqno designation journal *"
+#
 
 class Plan(UserPlan):
     class Meta:
@@ -227,22 +246,38 @@ class Plan(UserPlan):
         verbose_name = _("Invoicing plan")
         verbose_name_plural = _("Invoicing plans")
 
-    area = dd.ForeignKey('invoicing.Area', blank=True)
+    invoicing_area = InvoicingAreas.field(default="default")
+    target_journal = dd.ForeignKey('ledger.Journal', blank=True, null=True)
     min_date = models.DateField(_("Invoiceables from"), null=True, blank=True)
     max_date = models.DateField(_("until"), null=True, blank=True)
-    order = dd.ForeignKey(order_model, blank=True, null=True)
     partner = dd.ForeignKey('contacts.Partner', blank=True, null=True)
+    order = dd.ForeignKey(order_model, blank=True, null=True)
 
     start_plan = StartInvoicing()
     execute_plan = ExecutePlan()
+    toggle_selections = ToggleSelection()
+
+    def __str__(self):
+        # return "{0} {1}".format(self._meta.verbose_name, self.user)
+        # return self._meta.verbose_name
+        return str(self.user)
+
+    @dd.chooser()
+    def target_journal_choices(cls, invoicing_area):
+        if invoicing_area:
+            return invoicing_area.get_target_journals()
+        return []
 
     def full_clean(self):
-        if self.area_id is None:
-            self.area = rt.models.invoicing.Area.objects.first()
-            if self.area is None:
-                raise Warning(
-                    _("Please configure at least one invoicing area."))
-        super(Plan, self).full_clean()
+        # if not self.invoicing_area:
+        #     if self.order:
+        #         self.invoicing_area = FollowUpRule.find_for_model(self.order.__class__).invoicing_area
+        super().full_clean()
+        if self.target_journal is None:
+            self.target_journal = self.invoicing_area.get_target_journals().first()
+        if not issubclass(self.target_journal.voucher_type.model, dd.plugins.invoicing.voucher_model):
+            raise ValidationError("Journal {} is not on {}".format(
+                self.target_journal, dd.plugins.invoicing.voucher_model))
 
     def get_max_date(self):
         if self.max_date:
@@ -264,23 +299,21 @@ class Plan(UserPlan):
         self.fill_plan(ar)
 
     def fill_plan(self, ar):
+        # print("20221224 fill plan.target_journal is", self.target_journal)
         self.full_clean()
         Item = rt.models.invoicing.Item
         collected = dict()
         max_date = self.get_max_date()
-        for ig in self.get_generators_for_plan():
+        for ig in self.get_generators_for_plan(self.partner):
             partner = ig.get_invoiceable_partner()
-            # print("20220507 partner", partner)
+            # print("20221218", ig, partner)
             if partner is None:
                 continue
                 # raise Exception("{!r} has no invoice recipient".format(
                 #     ig))
-
             partner = get_invoice_recipient(partner)
-            invoice = self.create_invoice(
-                partner=partner, user=ar.get_user())
+            invoice = self.create_invoice(partner=partner, user=ar.get_user())
 
-            # dd.logger.info("20181114 b", obj)
             info = ig.compute_invoicing_info(self.min_date, max_date)
             # if not info.invoiceable_product:
             #     continue
@@ -291,7 +324,7 @@ class Plan(UserPlan):
                 # dd.logger.info("20181126 no invoice items for %s", ig)
                 continue
 
-            # print("20210731", partner, invoice_items)
+            # print("20221223 gonna make invoice", invoice, invoice_items)
 
             # assert invoice.pk is None
             # for i in invoice_items:
@@ -344,24 +377,22 @@ class Plan(UserPlan):
     def create_invoice(self, **kwargs):
         # ITEM_MODEL = dd.plugins.invoicing.item_model
         # M = dd.plugins.invoicing.default_voucher_view.model
-        M = self.area.journal.voucher_type.model
+        # source_journal = self.invoicing_area.source_journal
+        # M = self.source_journal.voucher_type.model
+        M = dd.plugins.invoicing.voucher_model
         # M = ITEM_MODEL._meta.get_field('voucher').remote_field.model
         kwargs.update(
-            journal=self.area.journal,
+            journal=self.target_journal,
             entry_date=self.today)
-            # invoicing_min_date=self.min_date,
-            # invoicing_max_date=self.get_max_date())
+        # print("20221217 gonna create", M)
+        # if issubclass(M, dd.plugins.invoicing.voucher_model):
+        kwargs.update(
+            invoicing_min_date=self.min_date,
+            invoicing_max_date=self.get_max_date())
         invoice = M(**kwargs)
         invoice.fill_defaults()
         return invoice
 
-    toggle_selections = ToggleSelection()
-
-    def __str__(self):
-        # return "{0} {1}".format(self._meta.verbose_name, self.user)
-        # return self._meta.verbose_name
-        return str(self.user)
-
 
 class Item(dd.Model):
     class Meta:
@@ -415,10 +446,10 @@ class Item(dd.Model):
         return ''
 
     def create_invoice(self,  ar):
-        if self.plan.area_id is None:
-            raise Warning(_("No area specified"))
-        if self.plan.area.journal is None:
-            raise Warning(_("No journal configured for {}").format(self.plan.area))
+        if self.plan.invoicing_area is None:
+            raise Warning(_("No invoicing_area specified"))
+        if self.plan.target_journal is None:
+            raise Warning(_("No target journal specified for {}").format(self.plan.invoicing_area))
         invoice = self.plan.create_invoice(
             partner=self.partner, user=ar.get_user())
         lng = invoice.get_print_language()
@@ -441,11 +472,11 @@ class Item(dd.Model):
                 if pt:
                     invoice.paper_type = pt
 
-                ig.setup_invoice_from_suggestion(invoice, self.plan, info)
+                # ig.setup_invoice_from_suggestion(invoice, self.plan, info)
 
-                # for i in ig.get_invoice_items(info, ITEM_MODEL, ar):
                 for i in ig.get_invoice_items(info, invoice, ar):
-                    i.invoiceable = ig
+                    if i.product == info.invoiceable_product:
+                        i.invoiceable = ig
                     # kwargs.update(voucher=invoice)
                     # i = ITEM_MODEL(**kwargs)
                     # if 'amount' in kwargs:
@@ -496,21 +527,31 @@ class Item(dd.Model):
     def __str__(self):
         return "{0} {1}".format(self.plan, self.partner)
 
+
 class Plans(dd.Table):
     required_roles = dd.login_required(LedgerUser)
     model = "invoicing.Plan"
-    detail_layout = """user area today min_date max_date
-    partner order
+    detail_layout = """
+    user invoicing_area target_journal
+    partner order today min_date max_date
     invoicing.ItemsByPlan
     """
 
-
 class MyPlans(My, Plans):
     pass
 
-# class PlansByArea(Plans):
-#     master_key = 'area'
-#     start_invoicing = StartInvoicingByArea()
+class PlansByArea(Plans):
+    master_key = 'invoicing_area'
+    # detail_layout = """user source_journal partner
+    # order today min_date max_date
+    # invoicing.ItemsByPlan
+    # """
+    start_invoicing = StartInvoicingByArea()
+
+    @classmethod
+    def get_master_instance(self, ar, model, pk):
+        return InvoicingAreas.get_by_value(pk)
+
 
 class AllPlans(Plans):
     required_roles = dd.login_required(LedgerStaff)
@@ -526,6 +567,9 @@ class ItemsByPlan(Items):
     master_key = 'plan'
     row_height = 2
     column_names = "selected partner preview amount invoice_button *"
+    display_mode = (
+        (None, constants.DISPLAY_MODE_TABLE),
+    )
 
 
 class InvoicingsByGenerator(dd.Table):
@@ -542,46 +586,55 @@ dd.inject_field(
     'products.Product', 'tariff', dd.ForeignKey(
         'invoicing.Tariff', blank=True, null=True))
 
-VOUCHER_MODEL = dd.plugins.invoicing.voucher_model
-dd.inject_field(
-    VOUCHER_MODEL, 'invoicing_min_date', dd.DateField(
-        _("Invoiceables from"), blank=True, null=True))
-dd.inject_field(
-    VOUCHER_MODEL, 'invoicing_max_date', dd.DateField(
-        _("until"), blank=True, null=True))
+# VOUCHER_MODEL = dd.plugins.invoicing.voucher_model
+# dd.inject_field(
+#     VOUCHER_MODEL, 'invoicing_min_date', dd.DateField(
+#         _("Invoiceables from"), blank=True, null=True))
+# dd.inject_field(
+#     VOUCHER_MODEL, 'invoicing_max_date', dd.DateField(
+#         _("until"), blank=True, null=True))
+
+# dd.inject_field(
+#     'ledger.Journal', 'invoicing_area',
+#     InvoicingAreas.field(null=True, blank=True))
+
+# dd.inject_field(
+#     'ledger.Journal', 'invoiceable_product',
+#     dd.ForeignKey('products.Product', blank=True, null=True))
 
-dd.inject_field(
-    dd.plugins.invoicing.item_model,
-    'invoiceable_type', dd.ForeignKey(
-        ContentType,
-        blank=True, null=True,
-        verbose_name=format_lazy(u"{} {}",invoiceable_label, _('(type)'))))
-dd.inject_field(
-    dd.plugins.invoicing.item_model,
-    'invoiceable_id', GenericForeignKeyIdField(
-        'invoiceable_type',
-        blank=True, null=True,
-        verbose_name=format_lazy(u"{} {}",invoiceable_label, _('(object)'))))
-dd.inject_field(
-    dd.plugins.invoicing.item_model,
-    'invoiceable', GenericForeignKey(
-        'invoiceable_type', 'invoiceable_id',
-        verbose_name=invoiceable_label))
 
 # dd.inject_field(
 #     dd.plugins.invoicing.item_model,
-#     'item_no', models.IntegerField(_("Iten no."))
-
-# define a custom chooser because we want to see only invoiceable
-# models when manually selecting an invoiceable_type:
-@dd.chooser()
-def invoiceable_type_choices(cls):
-    return ContentType.objects.get_for_models(
-        *rt.models_by_base(InvoiceGenerator)).values()
-
-dd.inject_action(
-    dd.plugins.invoicing.item_model,
-    invoiceable_type_choices=invoiceable_type_choices)
+#     'invoiceable_type', dd.ForeignKey(
+#         ContentType,
+#         blank=True, null=True,
+#         verbose_name=format_lazy("{} {}",invoiceable_label, _('(type)'))))
+# dd.inject_field(
+#     dd.plugins.invoicing.item_model,
+#     'invoiceable_id', GenericForeignKeyIdField(
+#         'invoiceable_type',
+#         blank=True, null=True,
+#         verbose_name=format_lazy("{} {}",invoiceable_label, _('(object)'))))
+# dd.inject_field(
+#     dd.plugins.invoicing.item_model,
+#     'invoiceable', GenericForeignKey(
+#         'invoiceable_type', 'invoiceable_id',
+#         verbose_name=invoiceable_label))
+#
+# # dd.inject_field(
+# #     dd.plugins.invoicing.item_model,
+# #     'item_no', models.IntegerField(_("Iten no."))
+#
+# # define a custom chooser because we want to see only invoiceable
+# # models when manually selecting an invoiceable_type:
+# @dd.chooser()
+# def invoiceable_type_choices(cls):
+#     return ContentType.objects.get_for_models(
+#         *rt.models_by_base(InvoiceGenerator)).values()
+#
+# dd.inject_action(
+#     dd.plugins.invoicing.item_model,
+#     invoiceable_type_choices=invoiceable_type_choices)
 
 
 # 20181115 : note this feature doesn't work when a generator creates
