@@ -27,42 +27,11 @@ class Plugin(ad.Plugin):
     needs_plugins = ['lino.modlib.weasyprint', 'lino_xl.lib.xl', 'lino.modlib.uploads']
 
     ref_length = 4  # 20
-    """
-    The `max_length` of the `Reference` field of an account.
-    """
 
     currency_symbol = "€"
-    """
-    Temporary approach until we add support for multiple currencies.
-    See also :meth:`lino.core.site.Site.format_currency`.
-    """
-
     use_pcmn = False
-    """
-    Whether to use the PCMN notation.
-
-    PCMN stands for "plan compatable minimum normalisé" and is a
-    standardized nomenclature for accounts used in France and
-    Belgium.
-
-    """
     project_model = None
-    """
-    Leave this to `None` for normal behaviour.  Set this to a
-    string of the form `'<app_label>.<ModelName>'` if you want to
-    add an additional field `project` to all models which inherit
-    from :class:`lino_xl.lib.ledger.ProjectRelated`.
-    """
-
     worker_model = None
-    """
-    The model to use for workers.
-
-    Default value is `None`.  If this is set to a model name (e.g.
-    'contacts.Person'), Lino will add a field
-    :class:`lino_xl.lib.ledger.PaymentTerm.worker`.
-
-    """
 
     # intrusive_menu = False
     # """
@@ -75,31 +44,21 @@ class Plugin(ad.Plugin):
     # """
     #
     start_year = 2012
-    """
-    An integer with the calendar year in which this site starts
-    working.
-
-    This is used to fill the default list of :class:`FiscalYears`,
-    and by certain fixtures for generating demo invoices.
-    """
-
     fix_y2k = False
-    """
-    Whether to use a Y2K compatible representation for fiscal years.
-    """
-
     suppress_movements_until = None
-    """
-    Don't create any movements before that date.  Vouchers can exist
-    and get registered before that date, but they don't have any
-    influence to the ledger.
 
-    This is useful e.g. when you want to keep legacy vouchers in your
-    database but not their movments.
-    """
+    # Available sales methods:
+    SALES_METHODS = {
+        'direct' : "just invoices",
+        'delivery' : "delivery notes and invoices",
+        'pos' : "point of sales",
+    }
 
-    sales_stories = True
-    """Whether demo fixtures should generate manual sales invoices."""
+    sales_method = 'direct'
+    has_payment_methods = False
+
+
+    # sales_stories_journal = "SLS"
 
     # purchase_stories = True
     # """Whether demo fixture should generate purchase invoices."""
@@ -113,13 +72,19 @@ class Plugin(ad.Plugin):
     #
     # """
 
-    # def on_site_startup(self, site):
-    #     if isinstance(self.registered_states, str):
-    #         s = {
-    #             site.models.ledger.VoucherStates.get_by_name(i)
-    #                 for i in self.registered_states.split()}
-    #         self.registered_states = tuple(s)
-    #     super(Plugin, self).on_site_startup(site)
+    def on_site_startup(self, site):
+        # if isinstance(self.registered_states, str):
+        #     s = {
+        #         site.models.ledger.VoucherStates.get_by_name(i)
+        #             for i in self.registered_states.split()}
+        #     self.registered_states = tuple(s)
+        if self.sales_method is not None:
+            if self.sales_method not in self.SALES_METHODS:
+                raise Exception(
+                "Invalid value {} for ledger.sales_method!".format(self.sales_method))
+            if self.sales_method == 'pos' and not self.has_payment_methods:
+                raise Exception("When sales_method is 'pos', has_payment_methods must be True.")
+        super(Plugin, self).on_site_startup(site)
 
     def post_site_startup(self, site):
         super(Plugin, self).post_site_startup(site)
@@ -174,7 +139,8 @@ class Plugin(ad.Plugin):
         m.add_action('ledger.FiscalYears')
         m.add_action('ledger.AccountingPeriods')
         m.add_action('ledger.PaymentTerms')
-        m.add_action('ledger.PaymentMethods')
+        if self.has_payment_methods:
+            m.add_action('ledger.PaymentMethods')
 
     def setup_explorer_menu(self, site, user_type, m):
         mg = site.plugins.ledger
