@@ -110,7 +110,7 @@ class CommonAccount(dd.Choice):
 
     def __init__(self, value, text, name, clearable, **kwargs):
         # the class attribute `name` ís used as value
-        super(CommonAccount, self).__init__(value, text, name, **kwargs)
+        super().__init__(value, text, name, **kwargs)
         # self.sheet_item = CommonItems.get_by_name(actype)
         # self.clearable = clearable
         self.clearable = clearable
@@ -125,8 +125,7 @@ class CommonAccount(dd.Choice):
         #     kwargs.update(sheet_item=self.sheet_item.get_object())
         # else:
         #     kwargs.pop('sheet_item', None)
-        return rt.models.ledger.Account(
-            ref=self.value, **kwargs)
+        return rt.models.ledger.Account(ref=self.value, **kwargs)
 
     def set_object(self, obj):
         self._instance = obj
@@ -215,11 +214,10 @@ class VoucherType(dd.Choice):
             text = format_lazy("{} ({})", model._meta.verbose_name, value)
         #     model.__module__, model.__name__)
         name = None
-        super(VoucherType, self).__init__(value, text, name)
+        super().__init__(value, text, name)
 
     def get_items_model(self):
-        """Returns the class object of the model used for storing items of
-        vouchers of this type.
+        """Returns the model used for storing items of vouchers of this type.
 
         """
         return self.model.items.rel.related_model
