@@ -4,7 +4,7 @@
 
 """Defines the :manage:`reregister` admin command.
 
-See :doc:`/specs/ledger`.
+See :doc:`/plugins/ledger`.
 
 """
 
