@@ -29,11 +29,12 @@ from lino.utils import mti
 from lino_xl.lib.contacts.choicelists import PartnerEvents
 from lino_xl.lib.vat.choicelists import VatClasses, VatColumns
 from lino_xl.lib.excerpts.mixins import Certifiable
+from lino_xl.lib.invoicing.mixins import InvoicingAreas
 
 from .utils import myround
 from .choicelists import CommonAccounts
 from .choicelists import DC, PeriodStates
-from .mixins import ProjectRelated, VoucherNumber, PeriodRange, PeriodRangeObservable, PartnerRelated, Payable
+from .mixins import ProjectRelated, VoucherNumber, PeriodRange, PeriodRangeObservable, PaymentRelated, Payable
 from .roles import VoucherSupervisor
 from .ui import *
 
@@ -46,8 +47,7 @@ class LedgerInfo(dd.Model):
 
     allow_cascaded_delete = 'user'
     user = dd.OneToOneField('users.User', primary_key=True)
-    entry_date = models.DateField(
-        _("Last entry date"), null=True, blank=True)
+    entry_date = models.DateField(_("Last entry date"), null=True, blank=True)
 
     @classmethod
     def get_for_user(cls, user):
@@ -69,10 +69,8 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
     trade_type = TradeTypes.field(blank=True)
     voucher_type = VoucherTypes.field()
     journal_group = JournalGroups.field()
-    auto_check_clearings = models.BooleanField(
-        _("Check clearing"), default=True)
-    auto_fill_suggestions = models.BooleanField(
-        _("Fill suggestions"), default=True)
+    auto_check_clearings = models.BooleanField(_("Check clearing"), default=True)
+    auto_fill_suggestions = models.BooleanField(_("Fill suggestions"), default=True)
     force_sequence = models.BooleanField(
         _("Force chronological sequence"), default=False)
     preliminary = models.BooleanField(_("Preliminary"), default=False)
@@ -83,16 +81,14 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
         _("Printed document designation"), max_length=100, blank=True)
     dc = DC.field(_("Primary booking direction"), blank=True, null=True)
     # dc = DebitOrCreditField(_("Primary booking direction"))
-    yearly_numbering = models.BooleanField(
-        _("Yearly numbering"), default=True)
+    yearly_numbering = models.BooleanField(_("Yearly numbering"), default=True)
     must_declare = models.BooleanField(default=True)
     uploads_volume = dd.ForeignKey("uploads.Volume", blank=True, null=True)
     # invert_due_dc = models.BooleanField(
     #     _("Invert booking direction"),
     #     help_text=_("Whether to invert booking direction of due movement."),
     #     default=True)
-    invoicing_area = dd.ForeignKey('invoicing.Area', blank=True, null=True,
-        related_name="journals_using_this")
+    invoicing_area = InvoicingAreas.field(null=True, blank=True)
 
     def get_doc_model(self):
         """The model of vouchers in this Journal.
@@ -196,7 +192,14 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
             self.name = self.id
         #~ if not self.pos:
             #~ self.pos = self.__class__.objects.all().count() + 1
-        super(Journal, self).full_clean(*args, **kw)
+        if self.invoicing_area:
+            if not issubclass(self.voucher_type.model, dd.plugins.invoicing.voucher_model):
+                tpl = "Journal {} can't be invoicing target because {} is not subclass of {}"
+                raise ValidationError(tpl.format(
+                    self, self.voucher_type.model, dd.plugins.invoicing.voucher_model))
+
+        super().full_clean(*args, **kw)
+
 
     def disable_voucher_delete(self, doc):
         # print "pre_delete_voucher", doc.number, self.get_next_number()
@@ -522,8 +525,7 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
     journal = JournalRef()
     entry_date = models.DateField(_("Entry date"))
     voucher_date = models.DateField(_("Voucher date"))
-    accounting_period = dd.ForeignKey(
-        'ledger.AccountingPeriod', blank=True)
+    accounting_period = dd.ForeignKey('ledger.AccountingPeriod', blank=True)
     number = VoucherNumber(_("No."), blank=True, null=True)
     narration = models.CharField(_("Narration"), max_length=200, blank=True)
 
@@ -659,6 +661,9 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
     def get_trade_type(self):
         return self.journal.trade_type
 
+    def get_printable_type(self):
+        return self.journal
+
     def get_printed_name(self):
         return dd.babelattr(self.journal, 'printed_name')
 
@@ -820,7 +825,8 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
 
     def get_invoicing_area(self):
         # used by InvoiceGenerator.
-        return self.journal.invoicing_area
+        # return self.journal.invoicing_area
+        pass
 
 
 Voucher.set_widget_options('number_with_year', width=10)
@@ -828,7 +834,7 @@ Voucher.set_widget_options('number_with_year', width=10)
 
 
 class ToggleState(dd.Action):
-    # show_in_bbar = False
+    # show_in_toolbar = False
     # button_text = _("Toggle state")
     # sort_index = 52
     label = _("Toggle state")
@@ -935,7 +941,7 @@ class RegistrableVoucher(Registrable, Voucher):
         self.do_and_clear(doit, do_clear)
 
 
-class Declaration(PartnerRelated, Payable, RegistrableVoucher, Certifiable, PeriodRange):
+class Declaration(PaymentRelated, Payable, RegistrableVoucher, Certifiable, PeriodRange):
     class Meta:
         abstract = True
         app_label = "ledger"
