@@ -3,8 +3,8 @@ from lino.api import dd, rt
 from lino_xl.lib.mailbox.models import get_new_mail
 def objects():
     Mailbox = rt.models.django_mailbox.Mailbox
-    # mp = rt.settings.SITE.cache_dir.child("media", "mailbox")
-    mp = rt.settings.SITE.cache_dir / "media" / "messages"
+    # mp = rt.settings.SITE.site_dir.child("media", "mailbox")
+    mp = rt.settings.SITE.site_dir / "media" / "messages"
     rt.settings.SITE.makedirs_if_missing(mp)
     # dd.logger.info("Mailbox path is %s", mp)
 
