@@ -1,9 +1,9 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2019-2020 Rumma & Ko Ltd
+# Copyright 2019-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 # from decimal import Decimal
-from lino_xl.lib.ledger.utils import ZERO, ONE
+from etgen.html import E, join_elems, tostring
 
 from django.db import models
 from django.db.models import Q
@@ -12,16 +12,16 @@ from django.core.exceptions import ValidationError
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy as pgettext
 from django.utils.text import format_lazy
-from etgen.html import E, join_elems, tostring
 
 from lino.api import dd, rt
-from lino import mixins
+from lino.utils.dates import DateRangeValue
 
 from lino.mixins import ProjectRelated
 from lino.mixins.human import parse_name
 from lino.mixins.duplicable import Duplicable
 from lino.mixins.periods import DateRange
 # from lino.mixins.registrable import Registrable
+from lino_xl.lib.ledger.utils import ZERO, ONE
 from lino_xl.lib.excerpts.mixins import Certifiable
 from lino_xl.lib.excerpts.mixins import ExcerptTitle
 from lino.modlib.users.mixins import UserAuthored
@@ -39,8 +39,6 @@ from lino_xl.lib.ledger.mixins import SequencedVoucherItem
 # from lino_xl.lib.sales.mixins import SalesDocument, ProductDocItem
 from lino_xl.lib.excerpts.mixins import Certifiable
 
-from lino.utils.dates import DateRangeValue
-
 # from .actions import PrintPresenceSheet
 from .choicelists import OrderStates
 
@@ -116,7 +114,7 @@ class Order(
     # order_state = OrderStates.field(default='draft')
 
     # subscription_type = dd.ForeignKey('invoicing.SubscriptionType')
-    invoicing_periodicity = Periodicities.field(blank=True, null=True)
+    subscription_periodicity = Periodicities.field(blank=True, null=True)
 
     # quick_search_fields = 'name'
 
@@ -129,9 +127,9 @@ class Order(
     # enrolments_until = models.DateField(
     #     _("Enrolments until"), blank=True, null=True)
     #
-    # print_presence_sheet = PrintPresenceSheet(show_in_bbar=False)
+    # print_presence_sheet = PrintPresenceSheet(show_in_toolbar=False)
     # print_presence_sheet_html = PrintPresenceSheet(
-    #     show_in_bbar=False,
+    #     show_in_toolbar=False,
     #     build_method='weasy2html',
     #     label=format_lazy(u"{}{}",_("Presence sheet"), _(" (HTML)")))
 
@@ -179,7 +177,7 @@ class Order(
                 self.contact_person = p
         if self.partner is None:
             raise Warning(_("Either company or person must be given."))
-        super(Order, self).full_clean(*args, **kwargs)
+        super().full_clean(*args, **kwargs)
 
     # @dd.displayfield(_("Print"))
     # def print_actions(self, ar):
@@ -217,13 +215,13 @@ class Order(
 
     @classmethod
     def get_simple_parameters(cls):
-        for f in super(Order, cls).get_simple_parameters():
+        for f in super().get_simple_parameters():
             yield f
         yield 'journal__room'
 
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(Order, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
         yield 'name'
 
@@ -280,7 +278,7 @@ class Order(
         event.room = self.journal.room
         event.start_time = self.start_time
         event.end_time = self.end_time
-        super(Order, self).before_auto_event_save(event)
+        super().before_auto_event_save(event)
 
     @dd.displayfield(_("Calendar entries"))
     def events_text(self, ar=None):
@@ -306,10 +304,12 @@ class Order(
     def get_generators_for_plan(cls, plan, partner=None):
         # pre-select all Event objects that potentially will generate
         # an invoice.
-        qs = super(Order, cls).get_generators_for_plan(plan, partner)
+        qs = super().get_generators_for_plan(plan, partner)
 
-        if plan.area is not None:
-            qs = qs.filter(journal__invoicing_area=plan.area)
+        # if plan.invoicing_area is None:
+        #     raise Exception("20221217")
+
+        # qs = qs.filter(journal__invoicing_area=plan.invoicing_area)
 
         if plan.order is None:
             qs = qs.exclude(state=OrderStates.cancelled)
@@ -332,33 +332,16 @@ class Order(
             fldname = cls.get_partner_filter_field(partner)
             qs = cls.filter_by_invoice_recipient(qs, partner, fldname)
 
-            # qs = cls.add_partner_filter(qs, partner)
-            # if False:
-            #     q1 = models.Q(
-            #         company__salesrule__invoice_recipient__isnull=True, company__pk=partner.pk)
-            #     q2 = models.Q(company__salesrule__invoice_recipient=partner)
-            #     flt1 = models.Q(models.Q(q1 | q2), company__isnull=False)
-            #     q3 = models.Q(
-            #         contact_person__salesrule__invoice_recipient__isnull=True, contact_person__pk=partner.pk)
-            #     q4 = models.Q(contact_person__salesrule__invoice_recipient=partner)
-            #     flt2 = models.Q(models.Q(q3 | q4), company__isnull=True)
-            #     qs = qs.filter(flt1 | flt2)
-            # else:
-                # if isinstance(partner, rt.models.contacts.Company):
-                #     qs = qs.filter(company=partner)
-                # elif isinstance(partner, rt.models.contacts.Person):
-                #     qs = qs.filter(contact_person=partner)
-                # qs = qs.filter(
-                #     models.Q(company=partner) | models.Q(contact_person=partner))
-
         # dd.logger.info("20200518 %s (%d rows)", qs.query, qs.count())
         return qs.order_by('id')
 
     def get_invoice_items(self, info, invoice, ar):
         # dd.logger.info("20181116a %s", self)
-        for i in super(Order, self).get_invoice_items(info, invoice, ar):
+        # print("20221222 get_invoice_items()", self.items.all())
+        for i in super().get_invoice_items(info, invoice, ar):
             # print("20210731 a", i)
             yield i
+        # print("20221222 asset_to_buy is", info.number_of_events, info.asset_to_buy)
         if info.number_of_events is None and info.asset_to_buy is not None:
             for oi in self.items.all():
                 kwargs = dict(
@@ -384,14 +367,17 @@ class Order(
             return product.tariff
         return None
 
+    def get_invoiceable_start_date(self, max_date):
+        return self.start_date
+
     def get_invoiceable_end_date(self):
         return self.max_date
 
-    def get_invoiceable_start_date(self, max_date):
-        return self.entry_date
-
     def get_invoicing_periodicity(self, product):
-        return self.invoicing_periodicity
+        return self.subscription_periodicity
+
+    def get_invoiceable_title(self, number=None):
+        return str(self)
 
 
 
