@@ -21,7 +21,7 @@ from django.core.mail import EmailMultiAlternatives
 
 from lino import mixins
 from lino.api import dd
-from lino.core import actions
+from lino.core import actions, constants
 from lino.core.site import html2text
 from lino.modlib.uploads.mixins import UploadController
 from lino.modlib.gfks.mixins import Controllable
@@ -307,7 +307,7 @@ class MailsByController(Mails):
     master_key = 'owner'
     auto_fit_column_widths = True
     #~ label = _("Postings")
-    #~ display_mode_main = 'summary'
+    # display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
 
 class MailsByUser(Mails):
@@ -389,8 +389,7 @@ class Attachments(dd.Table):
 class AttachmentsByMail(Attachments):
     required_roles = dd.login_required(OfficeUser)
     master_key = 'mail'
-    display_mode_main = 'summary'
-
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
 class AttachmentsByController(Attachments):
     master_key = 'owner'
