@@ -267,7 +267,7 @@ class QuestionsByPoll(Questions):
 
 class ToggleChoice(dd.Action):
     readonly = False
-    show_in_bbar = False
+    show_in_toolbar = False
     parameters = dict(
         question=dd.ForeignKey("polls.Question"),
         choice=dd.ForeignKey("polls.Choice"),
