@@ -1,8 +1,9 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma 6 Ko Ltd
+# Copyright 2008-2022 Rumma 6 Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
+from django.conf import settings
 
 from lino.api import dd, rt, _
 from lino.mixins import Sequenced
@@ -129,7 +130,19 @@ class Product(BabelNamed, BabelPreviewable, Duplicable):
                 self.product_type = self.category.product_type or ProductTypes.default
             else:
                 self.product_type = ProductTypes.default
-        super(Product, self).full_clean()
+
+        drv = dd.plugins.products.barcode_driver
+        if drv and self.barcode:
+            drv.write_svg_file(self.barcode)
+        super().full_clean()
+
+    @dd.htmlbox()
+    def barcode_svg(self, ar=None):
+        if dd.plugins.products.barcode_driver and self.barcode:
+            return '<img src="{}" alt="{}"/>'.format(
+                settings.SITE.build_media_url('barcodes', self.barcode+".svg"),
+                self.barcode)
+        return "No barcode"
 
 
 dd.update_field(Product, 'body', verbose_name=_("Long description"))
@@ -220,6 +233,8 @@ def inject_pricefactor_fields(sender, **kw):
             pf.field_cls.field(blank=True))
 
 
+
+
 @dd.receiver(dd.post_startup)
 def setup_memo_commands(sender=None, **kwargs):
     # See :doc:`/specs/memo`
