@@ -27,7 +27,7 @@ class SalesDocuments(PartnerVouchers):
 
 #     label = _("Make copy")
 #     show_in_workflow = True
-#     show_in_bbar = False
+#     show_in_toolbar = False
 #     copy_item_fields = set('product total_incl unit_price qty'.split())
 
 #     parameters = dict(
@@ -119,7 +119,7 @@ class InvoiceDetail(dd.DetailLayout):
     """, label=_("More"))
 
     ledger = dd.Panel("""
-    #voucher_date journal accounting_period number #narration
+    #voucher_date journal accounting_period number #narration match
     vat.MovementsByVoucher
     """, label=_("Ledger"))
 
@@ -132,21 +132,21 @@ class InvoiceDetail(dd.DetailLayout):
 
     panel1 = dd.Panel("""
     entry_date
-    # order subject
+    payment_method
     payment_term
     due_date:20
     """)
 
     panel2 = dd.Panel("""
     partner
-    subject
     vat_regime
+    subject
     your_ref
     """)
 
     panel3 = dd.Panel("""
-    match
-    # payment_method
+    invoicing_min_date
+    invoicing_max_date
     paper_type
     printed
     """)  # sales_remark
@@ -189,6 +189,7 @@ class InvoicesByJournal(Invoices, ByJournal):
     params_panel_hidden = True
     params_layout = "partner start_period end_period #year state cleared "
     column_names = "number_with_year entry_date #due_date " \
+        "invoicing_min_date invoicing_max_date " \
         "partner " \
         "subject:10 total_incl " \
         "workflow_buttons *"
@@ -257,6 +258,7 @@ class InvoiceItemDetail(dd.DetailLayout):
     seqno product discount
     unit_price qty total_base total_vat total_incl
     title
+    invoiceable_type:15 invoiceable_id:15 invoiceable:50
     description"""
 
     window_size = (80, 20)
@@ -287,9 +289,9 @@ class ItemsByInvoice(InvoiceItems):
     required_roles = dd.login_required(LedgerUser)
     # column_names = "product title discount unit_price qty item_total *"
     if dd.plugins.vat.item_vat:
-        column_names = "product title discount unit_price qty total_incl *"
+        column_names = "product title discount unit_price qty total_incl invoiceable *"
     else:
-        column_names = "product title discount unit_price qty total_base *"
+        column_names = "product title discount unit_price qty total_base invoiceable *"
 
 
 """
