@@ -6,7 +6,7 @@
 Add functionality for producing accounting statements that work using "sheet
 items".  In practice this means the *Balance sheet* and the *Income statement*.
 
-See :doc:`/specs/sheets`.
+See :doc:`/plugins/sheets`.
 """
 
 import locale
