@@ -18,7 +18,7 @@ class Plugin(ad.Plugin):
     journal_ref = "SLS"
     """The reference of the journal where shopping invoices will be created."""
 
-    def get_quicklinks(self, user):
+    def get_quicklinks(self):
         yield 'shopping.MyCart.start_plan'
 
     def setup_main_menu(self, site, user_type, m):
