@@ -16,7 +16,7 @@ from lino.core.actions import CreateRow
 from lino.core.utils import db2param
 from lino.mixins.ref import Referrable
 from lino.mixins.periods import DateRange
-from lino.modlib.comments.mixins import Commentable, PrivateCommentsReader
+from lino.modlib.comments.mixins import Commentable, PrivateCommentsReader, CommentField
 from lino.modlib.notify.choicelists import MessageTypes
 from lino.modlib.memo.mixins import rich_text_to_elems
 from lino.modlib.uploads.mixins import UploadController
@@ -56,7 +56,7 @@ class QuickAssignTo(dd.Action):
     """
     label = _("Assign to")
     icon_name = None
-    show_in_bbar = False
+    show_in_toolbar = False
     no_params_window = True
     parameters = dict(
         assign_to=dd.ForeignKey("users.User"),
@@ -220,8 +220,6 @@ class Site(Referrable, ContactRelated, Starrable, DateRange):
     group = dd.ForeignKey('groups.Group', null=True, blank=True)
     hours_paid = dd.DurationField(_("Hours paid"), blank=True, null=True)
     private = models.BooleanField(_("Private"), default=False)
-    order = dd.ForeignKey(order_model, null=True, blank=True)
-        # order = dd.ForeignKey(dd.plugins.invoicing.order_model, null=True, blank=True)
 
     def __str__(self):
         return self.ref or self.name
@@ -355,7 +353,7 @@ dd.update_field(Site, 'contact_person', verbose_name=_("Contact person"))
 #     label = "\u2611"
 #     help_text = _("Mark this ticket as closed.")
 #     show_in_workflow = True
-#     show_in_bbar = False
+#     show_in_toolbar = False
 
 #     def get_action_permission(self, ar, obj, state):
 #         if obj.standby is not None or obj.closed is not None:
@@ -376,7 +374,7 @@ dd.update_field(Site, 'contact_person', verbose_name=_("Contact person"))
 #     label = "\u2609"
 #     help_text = _("Put this ticket into standby mode.")
 #     show_in_workflow = True
-#     show_in_bbar = False
+#     show_in_toolbar = False
 
 #     def get_action_permission(self, ar, obj, state):
 #         if obj.standby is not None or obj.closed is not None:
@@ -397,7 +395,7 @@ dd.update_field(Site, 'contact_person', verbose_name=_("Contact person"))
 #     label = "☀"  # "\u2600"
 #     help_text = _("Reactivate this ticket from standby mode or closed state.")
 #     show_in_workflow = True
-#     show_in_bbar = False
+#     show_in_toolbar = False
 
 #     def get_action_permission(self, ar, obj, state):
 #         if obj.standby is None and obj.closed is None:
@@ -418,7 +416,7 @@ class SpawnTicket(dd.Action):
     # label = "\u2611" "☑"
     # label = "⚇"  # "\u2687"
     # show_in_workflow = False
-    # show_in_bbar = False
+    # show_in_toolbar = False
     # goto_new = True
     params_layout = """
     ticket_summary
@@ -530,10 +528,15 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
         blank=True, null=True,
         help_text=_("Last user to make a comment"))
 
+    order = dd.ForeignKey(order_model, null=True, blank=True)
+        # order = dd.ForeignKey(dd.plugins.invoicing.order_model, null=True, blank=True)
+
     comments = GenericRelation('comments.Comment',
         content_type_field='owner_type', object_id_field='owner_id',
         related_query_name="ticket")
 
+    comment = CommentField()
+
     quick_assign_to_action = QuickAssignTo()
 
     @dd.displayfield(_("Assign to"),
