@@ -344,7 +344,7 @@ class Tickets(dd.Table):
             blank=True, null=True,
             help_text=_("Only that this user is not assigned to.")),
         interesting_for=dd.ForeignKey(
-            'contacts.Partner',
+            'contacts.Company',
             verbose_name=_("Interesting for"),
             blank=True, null=True,
             help_text=_("Only tickets interesting for this partner.")),
@@ -425,7 +425,7 @@ class Tickets(dd.Table):
 
         if pv.interesting_for:
             qs = qs.filter(
-                Q(site__company=pv.interesting_for))
+                Q(order__company=pv.interesting_for))
 
         if dd.is_installed('votes'):
             if pv.assigned_to:
