@@ -22,7 +22,7 @@ from lino.api import dd, rt, _
 from lino_xl.lib.ledger.choicelists import CommonAccounts
 from lino_xl.lib.ledger.choicelists import TradeTypes
 from lino_xl.lib.ledger.mixins import ProjectRelated, VoucherItem
-from lino_xl.lib.ledger.mixins import Payable, PartnerRelated
+from lino_xl.lib.ledger.mixins import Payable, PaymentRelated
 from lino_xl.lib.ledger.models import RegistrableVoucher, VoucherStates
 from lino_xl.lib.ledger.utils import ZERO, ONE, myround
 
@@ -308,7 +308,7 @@ class VatDocument(RegistrableVoucher, ProjectRelated, VatTotal):
 # dd.update_field(VatDocument, 'total_incl', verbose_name=_("Total to pay"))
 
 
-class VatVoucher(VatDocument, PartnerRelated, Payable):
+class VatVoucher(VatDocument, PaymentRelated, Payable):
     # todo: merge VatDocument and VatVoucher?
     class Meta:
         abstract = True
@@ -446,7 +446,7 @@ class QtyVatItemBase(VatItemBase):
         self.reset_totals(ar)
 
     def reset_totals(self, ar=None):
-        super(QtyVatItemBase, self).reset_totals(ar)
+        super().reset_totals(ar)
         # if self.voucher.edit_totals:
         #     if self.qty:
         #         if self.voucher.item_vat:
