@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2020 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
@@ -7,9 +7,11 @@ from lino.api import dd, _
 
 from lino.utils.quantities import ZERO_DURATION
 
+# class ReportingType(dd.Choice):
 class ReportingTypes(dd.ChoiceList):
     verbose_name = _("Reporting type")
     verbose_name_plural = _("Reporting types")
+    max_length = 6
 
 
 add = ReportingTypes.add_item
