@@ -1,19 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2018 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
-# from django.db import models
-# from django.utils import timezone
-
+from django.core.exceptions import ValidationError
+from lino.modlib.summaries.mixins import Summarized
 from lino.api import dd, rt, _
 
-# from lino.mixins.periods import Monthly
-# from lino.modlib.printing.mixins import DirectPrintAction
-# from lino.core.roles import SiteUser
-# from .roles import Worker
-# from lino_xl.lib.tickets.roles import Triager
-
 from .actions import StartTicketSession, EndTicketSession
 
 
@@ -63,3 +56,27 @@ class Workable(dd.Model):
                 ses = rt.models.working.Session(ticket=elem, user=me)
                 ses.full_clean()
                 ses.save()
+
+
+class SummarizedFromSession(Summarized):
+
+    class Meta:
+        abstract = True
+
+    def add_from_session(self, obj):
+        d = obj.get_duration()
+        if d:
+            rt = obj.get_reporting_type()
+            k = rt.name + '_hours'
+            value = getattr(self, k)
+            if value == -1:
+                return
+            value += d
+            fld = self._meta.get_field(k)
+            try:
+                value = fld.clean(value, self)
+                # print("20221107 {} is okay".format(value))
+            except ValidationError as e:
+                print(e)
+                value = -1
+            setattr(self, k, value)
