@@ -28,7 +28,7 @@ from lino_xl.lib.invoicing.mixins import InvoiceGenerator
 
 from .actions import EndThisSession, PrintActivityReport, EndTicketSession, ShowMySessionsByDay
 from .choicelists import ReportingTypes, ZERO_DURATION
-from .mixins import Workable
+from .mixins import Workable, SummarizedFromSession
 
 
 class SessionType(mixins.BabelNamed):
@@ -89,18 +89,32 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
     # print_activity_report = PrintActivityReport()
 
     def __str__(self):
-        if self.start_time and self.end_time:
-            return u"%s %s-%s" % (
+        if self.start_time:
+            return "%s %s" % (
                 self.start_date.strftime(settings.SITE.date_format_strftime),
-                self.start_time.strftime(settings.SITE.time_format_strftime),
-                self.end_time.strftime(settings.SITE.time_format_strftime))
+                self.start_time.strftime(settings.SITE.time_format_strftime))
+        elif self.start_date:
+            return self.start_date.strftime(settings.SITE.date_format_strftime)
+
+        # if self.start_time and self.end_time:
+        #     if self.end_date is None or self.start_time == self.end_time:
+        #         return "%s %s-%s" % (
+        #             self.start_date.strftime(settings.SITE.date_format_strftime),
+        #             self.start_time.strftime(settings.SITE.time_format_strftime),
+        #             self.end_time.strftime(settings.SITE.time_format_strftime))
+        #     return "%s %s-%s %s" % (
+        #         self.start_date.strftime(settings.SITE.date_format_strftime),
+        #         self.start_time.strftime(settings.SITE.time_format_strftime),
+        #         self.end_date.strftime(settings.SITE.date_format_strftime),
+        #         self.end_time.strftime(settings.SITE.time_format_strftime))
+
         return "%s # %s" % (self._meta.verbose_name, self.pk)
 
     def get_ticket(self):
         return self.ticket
 
     def on_create(self, ar):
-        super(Session, self).on_create(ar)
+        super().on_create(ar)
         if settings.USE_TZ:
             self.time_zone = self.user.time_zone or \
                              rt.models.about.TimeZones.default
@@ -132,7 +146,7 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
             if self.ticket_id:
                 self.ticket.on_worked(self)
 
-        super(Session, self).full_clean(*args, **kwargs)
+        super().full_clean(*args, **kwargs)
 
     def unused_save(self, *args, **kwargs):
         if not settings.SITE.loading_from_dump:
@@ -140,7 +154,7 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
                 self.start_date = dd.today()
             if self.start_time is None:
                 self.start_time = timezone.now().time()
-        super(Session, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     def get_reporting_type(self):
         if self.reporting_type:
@@ -155,7 +169,7 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
         return dd.plugins.working.default_reporting_type
 
     # def after_ui_save(self, ar, cw):
-    #     super(Session, self).after_ui_save(ar, cw)
+    #     super().after_ui_save(ar, cw)
     #     if self.ticket_id:
     #         self.ticket.on_worked(self, ar, cw)
 
@@ -175,7 +189,7 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
         removes :attr:`break_time` if specified.
 
         """
-        diff = super(Session, self).get_duration()
+        diff = super().get_duration()
         if diff and self.break_time:
             diff -= self.break_time
         return diff
@@ -209,8 +223,8 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
     #     return self.invoice_recipient
 
     def get_invoiceable_partner(self):
-        if self.ticket_id and self.ticket.site_id:
-            return self.ticket.site.get_invoiceable_partner()
+        if self.ticket_id and self.ticket.order_id:
+            return self.ticket.order.get_invoiceable_partner()
 
     def get_invoiceable_product(self, max_date=None):
         par = self.get_invoiceable_partner()
@@ -223,14 +237,18 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
     def get_invoiceable_qty(self):
         qty = self.get_duration()
         if qty is not None:
+            # print("20221220", qty, "-->", Duration(qty))
             return Duration(qty)
 
+    def get_invoiceable_title(self, number=None):
+        # return "{} {}".format(self, self.user)
+        return str(self)
+
     @classmethod
     def get_generators_for_plan(cls, plan, partner=None):
-        # pre-select all Event objects that potentially will generate
-        # an invoice.
+        # pre-select all objects that potentially will generate an invoice.
 
-        qs = super(Session, cls).get_generators_for_plan(plan, partner)
+        qs = super().get_generators_for_plan(plan, partner)
 
         max_date = plan.get_max_date()
         if max_date:
@@ -247,7 +265,12 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
             # raise Exception("20210731 {}".format(dd.plugins.invoicing.order_model))
             # qs = qs.filter(**gfk2lookup(cls.owner, plan.order))
             if dd.plugins.invoicing.order_model is rt.models.orders.Order:
-                qs = qs.filter(ticket__site__order=plan.order)
+                qs = qs.filter(ticket__order=plan.order)
+            else:
+                # sessions on a ticket without an order will never get invoiced
+                return []
+        else:
+            qs = qs.filter(ticket__order__isnull=False)
 
         # dd.logger.info("20181113 c %s", qs)
 
@@ -255,12 +278,13 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
             partner = plan.partner
 
         if partner is None:
-            # only with a partner (because only these get invoiced
-            # per course).
-            qs = qs.filter(ticket__site__company__isnull=False)
+            qs = qs.filter(ticket__order__isnull=False)
         else:
-            fldname = rt.models.tickets.Site.get_partner_filter_field(partner)
-            qs = cls.filter_by_invoice_recipient(qs, partner, 'ticket__site__'+fldname)
+            # fldname = rt.models.tickets.Site.get_partner_filter_field(partner)
+            # fldname = rt.models.orders.Order.get_partner_filter_field(partner)
+            fldname = dd.plugins.invoicing.order_model.get_partner_filter_field(partner)
+            qs = cls.filter_by_invoice_recipient(qs, partner, 'ticket__order__'+fldname)
+            # print("20221219", qs.query)
             # q1 = models.Q(
             #     ticket__site__company__salesrule__invoice_recipient__isnull=True,
             #     ticket__site__company=partner)
@@ -316,7 +340,7 @@ class ServiceReport(UserAuthored, ContactRelated, Certifiable, DateRange):
 dd.update_field(ServiceReport, 'user', verbose_name=_("Worker"))
 
 
-class SummaryBySession(MonthlySlaveSummary):
+class SummaryBySession(MonthlySlaveSummary, SummarizedFromSession):
     # common base for UserSummary and SiteSummary
 
     class Meta:
@@ -333,13 +357,13 @@ class SummaryBySession(MonthlySlaveSummary):
             k = t.name + '_hours'
             setattr(self, k, ZERO_DURATION)
 
-    def add_from_session(self, obj):
-        d = obj.get_duration()
-        if d:
-            rt = obj.get_reporting_type()
-            k = rt.name + '_hours'
-            value = getattr(self, k) + d
-            setattr(self, k, value)
+    # def add_from_session(self, obj):
+    #     d = obj.get_duration()
+    #     if d:
+    #         rt = obj.get_reporting_type()
+    #         k = rt.name + '_hours'
+    #         value = getattr(self, k) + d
+    #         setattr(self, k, value)
 
 
 class UserSummary(SummaryBySession):
@@ -389,14 +413,14 @@ class SiteSummary(SummaryBySession):
 
     @classmethod
     def get_summary_columns(cls):
-        for k in super(SiteSummary, cls).get_summary_columns():
+        for k in super().get_summary_columns():
             yield k
         yield 'active_tickets'
         yield 'inactive_tickets'
 
 
     def reset_summary_data(self):
-        super(SiteSummary, self).reset_summary_data()
+        super().reset_summary_data()
         # for ts in TicketStates.get_list_items():
         #     k = ts.get_summary_field()
         #     if k is not None:
@@ -437,14 +461,14 @@ def inject_summary_fields(sender, **kw):
     UserSummary = rt.models.working.UserSummary
     WorkSite = rt.models.tickets.Site
     Ticket = dd.plugins.working.ticket_model
+    options = dict(
+        max_length=dd.plugins.summaries.duration_max_length,
+        null=True, blank=True)
     for t in ReportingTypes.get_list_items():
         k = t.name + '_hours'
-        dd.inject_field(
-            SiteSummary, k, dd.DurationField(t.text, null=True, blank=True))
-        dd.inject_field(
-            UserSummary, k, dd.DurationField(t.text, null=True, blank=True))
-        dd.inject_field(
-            Ticket, k, dd.DurationField(t.text, null=True, blank=True))
+        dd.inject_field(SiteSummary, k, dd.DurationField(t.text, **options))
+        dd.inject_field(UserSummary, k, dd.DurationField(t.text, **options))
+        dd.inject_field(Ticket, k, dd.DurationField(t.text, **options))
 
         def make_getter(t):
             k = t.name + '_hours'
