@@ -30,6 +30,8 @@ from .roles import Worker
 from .choicelists import ReportingTypes
 from lino.core import constants
 
+reports_master = dd.get_plugin_setting('working', "reports_master")
+
 class TOTAL_KEY(object):
     pass
 
@@ -193,7 +195,7 @@ class SessionsByTicket(Sessions):
                 if sar.get_permission():
                     lnk = E.span(lnk, " ", sar.ar2button(ses))
                 active_sessions.append(lnk)
-            if ses.summary:
+            if False:  # ses.summary:
                 session_summaries.insert(0,
                     E.li(
                         "%s %s: %s"%(ses.user,
@@ -407,7 +409,7 @@ class DurationReport(VentilatedColumns):
 
     @classmethod
     def get_ventilated_columns(cls):
-        # yield the fields to be insered at {vcolumns} in template
+        # yield the fields to be inserted at {vcolumns} in template
         def w(rpttype, verbose_name):
             def func(fld, obj, ar):
                 return obj._root2tot.get(rpttype, None)
@@ -425,7 +427,8 @@ class DurationReport(VentilatedColumns):
         # yield w(None, _("N/A"))
 
 class SessionsByReport(Sessions, DurationReport):
-    master = 'working.ServiceReport'
+    master = reports_master
+    # master = 'working.ServiceReport'
 
     column_names_template = "start_date start_time end_time break_time " \
                             "my_description:50 user {vcolumns} *"
@@ -450,7 +453,7 @@ class SessionsByReport(Sessions, DurationReport):
             return
         spv = dict(start_date=mi.start_date, end_date=mi.end_date)
         # spv = mi.get_tickets_parameters()
-        spv.update(company=mi.interesting_for)
+        spv.update(company=mi.company)  # interesting_for
         spv.update(observed_event=dd.PeriodEvents.started)
         spv.update(user=mi.user)
         ar.param_values.update(spv)
@@ -475,7 +478,8 @@ class SessionsByReport(Sessions, DurationReport):
 
 class TicketsByReport(Tickets, DurationReport):
     """The list of tickets mentioned in a service report."""
-    master = 'working.ServiceReport'
+    # master = 'working.ServiceReport'
+    master = reports_master
     # column_names = "summary id reporter #project product site state
     # invested_time"
     column_names_template = "id detail_link end_user site state {vcolumns}"
@@ -493,7 +497,8 @@ class TicketsByReport(Tickets, DurationReport):
         pv = ar.param_values
 
         pv.update(start_date=mi.start_date, end_date=mi.end_date)
-        pv.update(interesting_for=mi.interesting_for)
+        # pv.update(interesting_for=mi.interesting_for)
+        pv.update(interesting_for=mi.company)
         pv.update(observed_event=TicketEvents.working)
 
         spv = dict(start_date=mi.start_date, end_date=mi.end_date)
@@ -513,7 +518,9 @@ class TicketsByReport(Tickets, DurationReport):
 from lino_xl.lib.tickets.ui import Sites
 
 class SitesByReport(Sites, DurationReport):
-    master = 'working.ServiceReport'
+    # master = 'working.ServiceReport'
+    master = reports_master
+
     # column_names = "summary id reporter #project product site state
     # invested_time"
     column_names_template = "name parsed_description hours_paid {vcolumns}"
@@ -531,7 +538,8 @@ class SitesByReport(Sites, DurationReport):
         pv = ar.param_values
 
         pv.update(start_date=mi.start_date, end_date=mi.end_date)
-        pv.update(interesting_for=mi.interesting_for)
+        # pv.update(interesting_for=mi.interesting_for)
+        pv.update(interesting_for=mi.company)
         pv.update(observed_event=TicketEvents.working)
 
         spv = dict(start_date=mi.start_date, end_date=mi.end_date)
@@ -540,7 +548,7 @@ class SitesByReport(Sites, DurationReport):
         # qs = super(SitesByReport, self).get_request_queryset(ar)
 
         qs = rt.models.tickets.Site.objects.filter(
-            company=mi.interesting_for)
+            company=mi.company)  # interesting_for
         for obj in qs:
             sar = SessionsBySite.request(
                 master_instance=obj, param_values=spv)
@@ -552,7 +560,7 @@ class SitesByReport(Sites, DurationReport):
                 yield obj
 
 
-# from lino.modlib.users.desktop import Users
+# from lino.modlib.users.ui import Users
 
 # class WorkersByReport(Users, DurationReport):
 
@@ -598,7 +606,7 @@ class ServiceReports(dd.Table):
     detail_layout = """
     id start_date end_date user interesting_for ticket_state printed
     company contact_person
-    SessionsByReport
+    # SessionsByReport
     # TicketsByReport
     # ProjectsByReport
     # CoursesByReport
@@ -669,8 +677,9 @@ class SummariesByUser(UserSummaries):
 # class WorkedHours(Days, dd.VentilatingTable):
 # class WorkedHours(CalendarView):
 # class WorkedHours(ParameterClone, DayNavigator, dd.VentilatingTable):
-class WorkedHours(ParameterClone, DaysTable, dd.VentilatingTable):
+class WorkedHours(DaysTable, dd.VentilatingTable):
     label = _("Worked hours")
+    # parameters = dict()
     # column_names_template = 'day_number long_date detail_link description {vcolumns}'
     column_names_template = 'detail_link worked_tickets {vcolumns} *'
     # reverse_sort_order = True
