@@ -6,7 +6,7 @@
 
 SETUP_INFO = dict(
     name='lino-xl',
-    version='22.10.2',
+    version='22.12.2',
     install_requires=['lino'],  # odfpy dependency now in lino_xl.lib.appypod
     tests_require=[],
     description="The Lino Extensions Library",
@@ -90,7 +90,6 @@ lino_xl.lib.eid_jslib
 lino_xl.lib.eid_jslib.beid
 lino_xl.lib.events
 lino_xl.lib.events.fixtures
-lino_xl.lib.events.tests
 lino_xl.lib.excerpts
 lino_xl.lib.excerpts.fixtures
 lino_xl.lib.orders
@@ -131,7 +130,6 @@ lino_xl.lib.stars
 lino_xl.lib.statbel
 lino_xl.lib.statbel.countries
 lino_xl.lib.statbel.countries.fixtures
-lino_xl.lib.thirds
 lino_xl.lib.topics
 lino_xl.lib.userstats
 lino_xl.lib.shopping
@@ -172,10 +170,11 @@ lino_xl.lib.working.fixtures
 lino_xl.lib.online
 lino_xl.lib.online.users
 lino_xl.lib.online.users.fixtures
-lino_xl.lib.votes
-lino_xl.lib.votes.fixtures
+lino_xl.lib.subscriptions
 lino_xl.lib.uploads
 lino_xl.lib.uploads.fixtures
+lino_xl.lib.votes
+lino_xl.lib.votes.fixtures
 """.splitlines() if n])
 
 SETUP_INFO.update(classifiers="""\
